from distutils.core import setup

setup(
    name='nesterPenn',
    version='1.0.0',
    py_modules=['nesterPenn'],
    author='pennli',
    author_email='lipeng1a@gmail.com',
    url='https://pypi.org/',
    description="Print item in list (of - possibly - nested lists)",
    long_description="Print item in list (of - possibly - nested lists)",
)

